@@ -1,7 +1,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright (C) 2008-2023 Univention GmbH
+# Copyright (C) 2008-2024 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -37,11 +37,15 @@ from configparser import (
     DuplicateOptionError, DuplicateSectionError, MissingSectionHeaderError, ParsingError, RawConfigParser,
 )
 from pathlib import Path
-from typing import Any, Dict, Iterable, Iterator, List
+from typing import TYPE_CHECKING, Any
 
 import univention.ucslint.base as uub
 
 
+if TYPE_CHECKING:
+    from collections.abc import Iterable, Iterator
+
+
 # Check 4
 # 1) Nach UCR-Templates suchen und prüfen, ob die Templates in einem info-File auftauchen
 # 2) In den UCR-Templates nach UCR-Variablen suchen (Code-Blöcke) und prüfen, ob diese in den info-Files registriert sind
@@ -57,7 +61,7 @@ import univention.ucslint.base as uub
 #
 # TODO / FIXME
 # - 0004-29: Different (conflicting) packages might provide the same Multifile with different definitions (e.g. univention-samba/etc/smb.conf)
-UcrInfo = Dict[str, List[str]]
+UcrInfo = dict[str, list[str]]
 
 
 class UniventionPackageCheck(uub.UniventionPackageCheckDebian):
@@ -171,7 +175,7 @@ class UniventionPackageCheck(uub.UniventionPackageCheckDebian):
     RE_FUNC_CUSTOM_USER = re.compile(r'(?: univention\.lib\.misc\. | ^\s* from \s+ univention\.lib\.misc \s+ import \s+ (?:\(.*?)? ) \b custom_username \b', re.MULTILINE | re.VERBOSE)
     RE_FUNC_CUSTOM_GROUP = re.compile(r'(?: univention\.lib\.misc\. | ^\s* from \s+ univention\.lib\.misc \s+ import \s+ (?:\(.*?)? ) \b custom_groupname \b', re.MULTILINE | re.VERBOSE)
 
-    def check_conffiles(self, paths: List[Path]) -> dict[Path, Any]:
+    def check_conffiles(self, paths: list[Path]) -> dict[Path, Any]:
         """Analyze UCR templates below :file:`conffiles/`."""
         conffiles: dict[Path, dict[str, Any]] = {}
 
