@@ -1,7 +1,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright (C) 2016-2023 Univention GmbH
+# Copyright (C) 2016-2024 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -36,7 +36,7 @@ import re
 from itertools import cycle
 from pathlib import Path
 from shlex import split
-from typing import Iterable, Iterator, Set
+from typing import TYPE_CHECKING
 
 from debian.changelog import Changelog, ChangelogParseError  # Version
 
@@ -44,6 +44,10 @@ import univention.ucslint.base as uub
 from univention.ucslint.common import RE_DEBIAN_PACKAGE_VERSION
 
 
+if TYPE_CHECKING:
+    from collections.abc import Iterable, Iterator
+
+
 class UniventionPackageCheck(uub.UniventionPackageCheckDebian):
 
     # https://www.debian.org/doc/debian-policy/ch-maintainerscripts.html#summary-of-ways-maintainer-scripts-are-called
@@ -92,7 +96,7 @@ class UniventionPackageCheck(uub.UniventionPackageCheckDebian):
         for script_path in paths:
             if script_path.suffix not in ('.%s' % suf for suf in self.SCRIPTS):
                 continue
-            package, suffix = self.split_pkg(script_path)
+            _package, suffix = self.split_pkg(script_path)
 
             other_scripts = self.SCRIPTS - {suffix}
             other_actions = {action for actions in self.ACTIONS.values() for action in actions} - self.ACTIONS[suffix]
@@ -129,7 +133,7 @@ class UniventionPackageCheck(uub.UniventionPackageCheckDebian):
                             script_path, row, line=line)
 
                 for match in self.RE_COMPARE_VERSIONS.finditer(line):
-                    ver_a, op, ver_b = match.groups()
+                    ver_a, _op, ver_b = match.groups()
                     for arg in (ver_a, ver_b):
                         if self.RE_ARG2.match(arg):
                             continue
@@ -224,7 +228,7 @@ class UniventionPackageCheck(uub.UniventionPackageCheckDebian):
         for fp in paths:
             if fp.suffix != '.install':
                 continue
-            package, suffix = self.split_pkg(fp)
+            package, _suffix = self.split_pkg(fp)
             pkg = dirs.setdefault(package, Dirs(package))
             # ~/doc/2018-04-11-ApiDoc/pymerge
             for row, line in self.lines(fp):
@@ -242,7 +246,7 @@ class UniventionPackageCheck(uub.UniventionPackageCheckDebian):
         for fp in paths:
             if fp.suffix != '.pyinstall':
                 continue
-            package, suffix = self.split_pkg(fp)
+            package, _suffix = self.split_pkg(fp)
             pkg = dirs.setdefault(package, Dirs(package))
             for row, line in self.lines(fp):
                 for src, dst in self.process_pyinstall(fp, line):
@@ -252,7 +256,7 @@ class UniventionPackageCheck(uub.UniventionPackageCheckDebian):
         for fp in paths:
             if fp.suffix != '.dirs':
                 continue
-            package, suffix = self.split_pkg(fp)
+            package, _suffix = self.split_pkg(fp)
             pkg = dirs.setdefault(package, Dirs(package))
             for row, line in self.lines(fp):
                 path = Path(line.strip('/'))
@@ -386,7 +390,7 @@ class UniventionPackageCheck(uub.UniventionPackageCheckDebian):
     RE_ARG2 = re.compile(r'^("?)\$(?:2|\{2[#%:?+=/-[^}]*\})(\1)$')
 
 
-class Dirs(Set[Path]):
+class Dirs(set[Path]):
     """Set of directories."""
 
     DIRS = frozenset({
@@ -431,7 +435,7 @@ class Version:
     '1:2.34alpha~5-6.7'
     """
 
-    __slots__ = ('text', 'numeric')
+    __slots__ = ('numeric', 'text')
 
     RE_VERSION = re.compile(r'([0-9]+)')
 
