@@ -3,7 +3,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2008-2023 Univention GmbH
+# Copyright 2008-2024 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -35,7 +35,12 @@ from __future__ import annotations
 import re
 from os import walk
 from pathlib import Path
-from typing import Callable, Dict, Iterable, Iterator, Match, Pattern, Tuple
+from re import Match, Pattern
+from typing import TYPE_CHECKING
+
+
+if TYPE_CHECKING:
+    from collections.abc import Callable, Iterable, Iterator
 
 
 try:
@@ -73,7 +78,7 @@ RESULT_INT2STR: dict[int, str] = {
     RESULT_STYLE: 'S',
 }
 
-MsgIds = Dict[str, Tuple[int, str]]
+MsgIds = dict[str, tuple[int, str]]
 
 RE_MSGID = re.compile(r'\d{4}-[BEFNW]?\d+')
 RE_IGNORE = re.compile(rf'\s+ ucslint :? \s* (?: ({RE_MSGID.pattern} (?: [, ]+ {RE_MSGID.pattern})*) \s* )? $', re.VERBOSE)
@@ -118,7 +123,7 @@ def line_regexp(text: str, regexp: Pattern[str]) -> Iterator[tuple[int, int, Mat
     col = 1
     pos = 0
     for match in regexp.finditer(text):
-        start, end = match.span()
+        start, _end = match.span()
         while pos < start:
             if text[pos] == "\n":
                 col = 1
@@ -280,7 +285,7 @@ class FailedToReadFile(UCSLintException):
         self.fn = fn
 
 
-class DebianControlEntry(Dict[str, str]):
+class DebianControlEntry(dict[str, str]):
     """
     Handle paragraph in Deb822 control file.
 
